"use strict";
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
var color_1 = require("@nativescript/core/color");
var loading_indicator_common_1 = require("./loading-indicator.common");
__export(require("./loading-indicator.common"));
var LoadingIndicator = (function () {
    function LoadingIndicator() {
    }
    LoadingIndicator.prototype.show = function (options) {
        if (typeof options === 'undefined')
            options = {};
        if (typeof this._hud === 'undefined') {
            this._targetView =
                options.ios && options.ios.view
                    ? options.ios.view
                    : this._getRootWindow();
            this._hud = MBProgressHUD.showHUDAddedToAnimated(this._targetView, true);
        }
        if (options.ios && options.ios.square)
            this._hud.square = true;
        if (options.message) {
            this._hud.label.text = options.message;
        }
        if (options.progress) {
            this._hud.progress = options.progress;
        }
        if (options.mode) {
            this._hud.mode = options.mode;
        }
        else {
            this._hud.mode = loading_indicator_common_1.Mode.Indeterminate;
        }
        if (options.dimBackground) {
            this._hud.backgroundView.style = 0;
            this._hud.backgroundView.color = new color_1.Color('#000').ios;
            this._hud.backgroundView.alpha = 0.3;
        }
        if (options.margin)
            this._hud.margin = options.margin;
        if (options.userInteractionEnabled)
            this._hud.userInteractionEnabled = options.userInteractionEnabled;
        if (options.backgroundColor) {
            this._hud.bezelView.blurEffectStyle = 4;
            this._hud.bezelView.backgroundColor = new color_1.Color(options.backgroundColor).ios;
        }
        if (options.color) {
            this._hud.contentColor = new color_1.Color(options.color).ios;
            this._hud.label.textColor = new color_1.Color(options.color).ios;
        }
        if (options.details) {
            this._hud.detailsLabel.text = options.details;
            this._hud.detailsLabel.textColor =
                options && options.color
                    ? new color_1.Color(options.color).ios
                    : new color_1.Color('#333').ios;
            this._hud.detailsLabel.alpha = 0.8;
        }
        if (options.hideBezel) {
            this._hud.backgroundColor = UIColor.clearColor;
            this._hud.bezelView.style = 0;
            this._hud.bezelView.backgroundColor = UIColor.clearColor;
        }
        if (this._hud.mode &&
            this._hud.mode === loading_indicator_common_1.Mode.CustomView &&
            options.customView) {
            if (options.customView instanceof UIImage) {
                this._hud.customView = UIImageView.alloc().initWithImage(options.customView);
            }
            else if (options.customView instanceof UIView) {
                this._hud.customView = options.customView;
            }
            else if (typeof options.customView === 'string') {
                this._hud.customView = UIImageView.alloc().initWithImage(UIImage.imageNamed(options.customView));
            }
        }
        return this._hud;
    };
    LoadingIndicator.prototype.hide = function (targetView) {
        targetView = targetView || this._targetView || this._getRootWindow();
        MBProgressHUD.hideHUDForViewAnimated(targetView, true);
        this._hud = undefined;
    };
    LoadingIndicator.prototype._getRootWindow = function () {
        return UIApplication.sharedApplication.windows[0];
    };
    return LoadingIndicator;
}());
exports.LoadingIndicator = LoadingIndicator;
//# sourceMappingURL=loading-indicator.ios.js.map